# Snapshot report for `test/js/deviceRegistrationTest.js`

The actual snapshot is saved in `deviceRegistrationTest.js.snap`.

Generated by [AVA](https://ava.li).

## structure

> Snapshot 1

    ServiceRequest {
      deviceRegistration: DeviceRegistration {
        correspondingClientIdentifier: 'someClientId',
        deviceType: 0,
        name: 'clientName',
      },
    }
